History of changes
==================

Version 1.1.2
-------------

Since early 2022, applications with embdded pdf are forbidden by some
Windows™ protections. ECCW used embedded pdf as a medium for its
documentation. The simplest solution to continue easy distribution of
ECCW is to avoid such embedded pdf. Epub is a nice alternative that
leaves paper sheet abstraction where it should belong : in the past.

Version 1.1.1
-------------

* all metadatas are now really centralised in setup.cfg
* eccw_gui module is now exectuable with python's option -m
* update and clean graphical ressources
* better pip packaging
  * sdist now really gets all sources
  * bdist gets desktop installation without root rights on linux
  * bdist gets scripts for manual post-installation on Windows
* automatize building of python code from Qt .ui and .qrc files
* automatize building of python distribution
* add CHANGELOG

Version 1.1.0
-------------

* asynchronize main app and plot window 
* reflow keyboard shortcuts
  * give numbers to parameters and associate them to shortcuts
    * 'FX' for selection of parameter to compute
    * 'Crtl+X' for edition of scalar version of parameter
    * 'Crtl+Alt+X' for edition of range version of parameter
  * give 'Crtl' shortcut to all buttons
  * give 'Alt' shortcut to all checkbox and aditional lineEdits
* reflow position of parameters in calculator an plot apps : 
  * context on left (which is now a groupBox of chekables)
  * friction in the middle
  * fluids on right
* better display of results in calculator app
* changes in code:
  * black formating, 
  * cleaning of useless code
  * renamings for clarity and better physical meaning




